==> confluence-create-content-plugin-7.0.0-sources.jar: com/atlassian/confluence/plugins/createcontent/extensions/DefaultUserBlueprintConfigManager.java <==
package com.atlassian.confluence.plugins.createcontent.extensions;

import com.atlassian.confluence.plugins.createcontent.ContentBlueprintManager;
import com.atlassian.confluence.plugins.createcontent.actions.BPUserPreferences;
import com.atlassian.confluence.plugins.createcontent.impl.ContentBlueprint;
import com.atlassian.confluence.user.ConfluenceUser;
import com.atlassian.confluence.user.UserAccessor;
import com.atlassian.plugin.ModuleCompleteKey;
import com.google.common.collect.Sets;
import com.opensymphony.module.propertyset.PropertySet;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;

import java.util.List;
import java.util.Set;
import java.util.UUID;

import static com.google.common.collect.Lists.newArrayList;
import static org.slf4j.LoggerFactory.getLogger;

/**
 * Default implementation of UserBlueprintConfigManager.
 */
public class DefaultUserBlueprintConfigManager implements UserBlueprintConfigManager {
    private static final Logger log = getLogger(DefaultUserBlueprintConfigManager.class);

    private static final String CREATED_BLUEPRINT_KEYS = "createdBlueprints";
    private static final String SKIP_HOW_TO_USE_BLUEPRINT_KEYS = "skip-how-to-use-blueprint-keys";

    private final UserAccessor userAccessor;
    private final ContentBlueprintManager contentBlueprintManager;

    public DefaultUserBlueprintConfigManager(UserAccessor userAccessor, ContentBlueprintManager contentBlueprintManager) {
        this.userAccessor = userAccessor;
        this.contentBlueprintManager = contentBlueprintManager;
    }

    @Override
    public Set<UUID> getSkipHowToUseKeys(ConfluenceUser user) {
        BPUserPreferences userPreferences = getUserPreferences(user);
        return getSkipKeys(userPreferences);
    }

    @Override
    public void setSkipHowToUse(ConfluenceUser user, UUID contentBlueprintId, boolean skip) {
        BPUserPreferences userPreferences = getUserPreferences(user);
        Set<UUID> skipKeys = getSkipKeys(userPreferences);
        if (skip)
            skipKeys.add(contentBlueprintId);
        else
            skipKeys.remove(contentBlueprintId);

        String keysStr = StringUtils.join(skipKeys, ",");
        userPreferences.setText(SKIP_HOW_TO_USE_BLUEPRINT_KEYS, keysStr);
    }

    @Override
    public boolean isFirstBlueprintOfTypeForUser(final UUID id, final ConfluenceUser user) {
        BPUserPreferences userPreferences = getUserPreferences(user);

        String blueprintKeys = userPreferences.getText(CREATED_BLUEPRINT_KEYS);
        return blueprintKeys == null || !blueprintKeys.contains(id.toString());
    }

    @Override
    public void setBlueprintCreatedByUser(final UUID id, final ConfluenceUser user) {
        BPUserPreferences userPreferences = getUserPreferences(user);
        String blueprintKeys = userPreferences.getText(CREATED_BLUEPRINT_KEYS);

        String idStr = id.toString();

        boolean modified = false;
        if (blueprintKeys == null) {
            blueprintKeys = idStr;
            modified = true;
        }
        if (!blueprintKeys.contains(idStr)) {
            blueprintKeys += ',' + idStr;
            modified = true;
        }
        if (modified) {
            userPreferences.setText(CREATED_BLUEPRINT_KEYS, blueprintKeys);
        }
    }

    public BPUserPreferences getUserPreferences(ConfluenceUser user) {
        PropertySet propertySet = userAccessor.getPropertySet(user);

        migratePrefs(propertySet, CREATED_BLUEPRINT_KEYS);
        migratePrefs(propertySet, SKIP_HOW_TO_USE_BLUEPRINT_KEYS);

        // TODO - cache these prefs per user. EG
        return new BPUserPreferences(propertySet);
    }

    private void migratePrefs(final PropertySet propertySet, final String key) {
        try {
            int type = propertySet.getType(key);
            if (type == 5) {
                String string = propertySet.getString(key);
                propertySet.remove(key);
                try {
                    String[] bpKeys = string.split(",");
                    List<String> uids = newArrayList();
                    for (String bpKey : bpKeys) {
                        ContentBlueprint pluginBlueprint = contentBlueprintManager.getPluginBlueprint(
                                new ModuleCompleteKey(bpKey));
                        if (pluginBlueprint != null) {
                            uids.add(pluginBlueprint.getId().toString());
                        }
                    }
                    propertySet.setText(key, StringUtils.join(uids, ','));
                } catch (Exception ex) {
                    log.warn("Unable to migrate Confluence Blueprint user preferences", ex);
                }
            }
        } catch (NullPointerException ex) {
            // Property not found. Some propertySet implementations are safe and return type 0, but some others just explode
        }
    }

    private Set<UUID> getSkipKeys(BPUserPreferences userPreferences) {
        String keysStr = userPreferences.getText(SKIP_HOW_TO_USE_BLUEPRINT_KEYS);
        if (StringUtils.isBlank(keysStr))
            return Sets.newHashSet();

        final String[] split = keysStr.split(",");
        Set<UUID> ids = Sets.newHashSet();
        for (String id : split) {
            ids.add(UUID.fromString(id));
        }

        return ids;
    }
}

==> confluence-create-content-plugin-12.1.1-sources.jar: com/atlassian/confluence/plugins/createcontent/extensions/DefaultUserBlueprintConfigManager.java <==
package com.atlassian.confluence.plugins.createcontent.extensions;

import com.atlassian.confluence.plugins.createcontent.ContentBlueprintManager;
import com.atlassian.confluence.plugins.createcontent.actions.BPUserPreferences;
import com.atlassian.confluence.plugins.createcontent.impl.ContentBlueprint;
import com.atlassian.confluence.user.ConfluenceUser;
import com.atlassian.confluence.user.UserAccessor;
import com.atlassian.plugin.ModuleCompleteKey;
import com.atlassian.plugin.spring.scanner.annotation.export.ExportAsService;
import com.atlassian.plugin.spring.scanner.annotation.imports.ComponentImport;
import com.google.common.collect.Sets;
import com.opensymphony.module.propertyset.PropertySet;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Set;
import java.util.UUID;

import static com.google.common.collect.Lists.newArrayList;
import static org.slf4j.LoggerFactory.getLogger;

/**
 * Default implementation of UserBlueprintConfigManager.
 */
@Component
@ExportAsService(UserBlueprintConfigManager.class)
public class DefaultUserBlueprintConfigManager implements UserBlueprintConfigManager {
    private static final Logger log = getLogger(DefaultUserBlueprintConfigManager.class);

    private static final String CREATED_BLUEPRINT_KEYS = "createdBlueprints";
    private static final String SKIP_HOW_TO_USE_BLUEPRINT_KEYS = "skip-how-to-use-blueprint-keys";

    private final UserAccessor userAccessor;
    private final ContentBlueprintManager contentBlueprintManager;

    @Autowired
    public DefaultUserBlueprintConfigManager(
            final @ComponentImport UserAccessor userAccessor,
            final ContentBlueprintManager contentBlueprintManager) {
        this.userAccessor = userAccessor;
        this.contentBlueprintManager = contentBlueprintManager;
    }

    @Override
    public Set<UUID> getSkipHowToUseKeys(ConfluenceUser user) {
        BPUserPreferences userPreferences = getUserPreferences(user);
        return getSkipKeys(userPreferences);
    }

    @Override
    public void setSkipHowToUse(ConfluenceUser user, UUID contentBlueprintId, boolean skip) {
        BPUserPreferences userPreferences = getUserPreferences(user);
        Set<UUID> skipKeys = getSkipKeys(userPreferences);
        if (skip)
            skipKeys.add(contentBlueprintId);
        else
            skipKeys.remove(contentBlueprintId);

        String keysStr = StringUtils.join(skipKeys, ",");
        userPreferences.setText(SKIP_HOW_TO_USE_BLUEPRINT_KEYS, keysStr);
    }

    @Override
    public boolean isFirstBlueprintOfTypeForUser(final UUID id, final ConfluenceUser user) {
        BPUserPreferences userPreferences = getUserPreferences(user);

        String blueprintKeys = userPreferences.getText(CREATED_BLUEPRINT_KEYS);
        return blueprintKeys == null || !blueprintKeys.contains(id.toString());
    }

    @Override
    public void setBlueprintCreatedByUser(final UUID id, final ConfluenceUser user) {
        BPUserPreferences userPreferences = getUserPreferences(user);
        String blueprintKeys = userPreferences.getText(CREATED_BLUEPRINT_KEYS);

        String idStr = id.toString();

        boolean modified = false;
        if (blueprintKeys == null) {
            blueprintKeys = idStr;
            modified = true;
        }
        if (!blueprintKeys.contains(idStr)) {
            blueprintKeys += ',' + idStr;
            modified = true;
        }
        if (modified) {
            userPreferences.setText(CREATED_BLUEPRINT_KEYS, blueprintKeys);
        }
    }

    public BPUserPreferences getUserPreferences(ConfluenceUser user) {
        PropertySet propertySet = userAccessor.getPropertySet(user);

        migratePrefs(propertySet, CREATED_BLUEPRINT_KEYS);
        migratePrefs(propertySet, SKIP_HOW_TO_USE_BLUEPRINT_KEYS);

        // TODO - cache these prefs per user. EG
        return new BPUserPreferences(propertySet);
    }

    private void migratePrefs(final PropertySet propertySet, final String key) {
        try {
            int type = propertySet.getType(key);
            if (type == 5) {
                String string = propertySet.getString(key);
                propertySet.remove(key);
                try {
                    String[] bpKeys = string.split(",");
                    List<String> uids = newArrayList();
                    for (String bpKey : bpKeys) {
                        ContentBlueprint pluginBlueprint = contentBlueprintManager.getPluginBlueprint(
                                new ModuleCompleteKey(bpKey));
                        if (pluginBlueprint != null) {
                            uids.add(pluginBlueprint.getId().toString());
                        }
                    }
                    propertySet.setText(key, StringUtils.join(uids, ','));
                } catch (Exception ex) {
                    log.warn("Unable to migrate Confluence Blueprint user preferences", ex);
                }
            }
        } catch (NullPointerException ex) {
            // Property not found. Some propertySet implementations are safe and return type 0, but some others just explode
        }
    }

    private Set<UUID> getSkipKeys(BPUserPreferences userPreferences) {
        String keysStr = userPreferences.getText(SKIP_HOW_TO_USE_BLUEPRINT_KEYS);
        if (StringUtils.isBlank(keysStr))
            return Sets.newHashSet();

        final String[] split = keysStr.split(",");
        Set<UUID> ids = Sets.newHashSet();
        for (String id : split) {
            ids.add(UUID.fromString(id));
        }

        return ids;
    }
}
